@@ -1,8 +1,9 @@
-#!/usr/bin/perl -T
+#!/usr/bin/perl
 use strict;
 use warnings;
 use File::Spec::Functions qw(curdir catdir splitdir rel2abs tmpdir updir);
 use Test::More qw(no_plan);
+use lib qw(../blib/lib);
 
 BEGIN {
     use_ok(qw(Cvs::Simple::Config));
